==> haskell-hls-change-type-signature-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-LOEktLxdz02LPTBoBFpSMi

key:
    hls-change-type-signature-plugin-2.1.0.0-LOEktLxdz02LPTBoBFpSMi

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  4915e08ae3ffcc4c896bb45b3a993130
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-LOEktLxdz02LPTBoBFpSMi

depends:
    base-4.17.2.1 containers-0.6.7
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA
    regex-tdfa-1.3.2.4-9ZyuPp8BFYO5HpZyySDZc8
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-change-type-signature-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-IzBVp2cqUNhGeQ6No8SrHa

key:
    hls-change-type-signature-plugin-2.1.0.0-IzBVp2cqUNhGeQ6No8SrHa

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  ce2b072de1ed268ca9e1506d11820e5c
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-IzBVp2cqUNhGeQ6No8SrHa

depends:
    base-4.17.2.1 containers-0.6.7 ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400
    regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
